@@ -7,6 +7,7 @@ python -m async_sched.client.run_command "print_task" "abc"
 import argparse
 import serial_json
 from async_sched.client.client import run_command
+from async_sched.utils import DEFAULT_HOST, DEFAULT_PORT
 
 
 __all__ = ['NAME', 'get_argparse', 'main']
@@ -22,7 +23,7 @@ def parse(value):
         return value
 
 
-def get_argparse(parent_parser=None):
+def get_argparse(host: str = DEFAULT_HOST, port: int = DEFAULT_PORT, parent_parser=None):
     if parent_parser is None:
         p = argparse.ArgumentParser(description='Run a registered command on the server.')
     else:
@@ -31,13 +32,13 @@ def get_argparse(parent_parser=None):
     p.add_argument('callback_name', help='Registered callback name to run.')
     p.add_argument('args', nargs='*', help='Positional arguments to pass into the callback function.')
 
-    p.add_argument('--host', type=str, default='127.0.0.1')
-    p.add_argument('--port', type=int, default=8000)
+    p.add_argument('--host', type=str, default=host)
+    p.add_argument('--port', type=int, default=port)
 
     return p
 
 
-def main(callback_name, args, host='127.0.0.1', port=8000, **kwargs):
+def main(callback_name: str, args: tuple, host: str = DEFAULT_HOST, port: int = DEFAULT_PORT, **kwargs):
     args = (parse(arg) for arg in args)
     run_command((host, port), callback_name, *args)
 
