@@ -1,4 +1,3 @@
 from .messages import Message, Error, Quit, Update, RunCommand, ScheduleCommand, \
     RunningSchedule, ListSchedules, StopSchedule
-from .srv import get_server, set_server, Scheduler
-from .client import Client
+from .srv import get_server, set_server, start_server, Scheduler
